@@ -17,6 +17,7 @@
  */
 
 #include <stdlib.h>
+#include <string.h>
 #include <errno.h>
 #include <error.h>
 
@@ -32,5 +33,11 @@ static inline void *calloc2( const size_t nmemb, const size_t size ) {
   return p;
 }
 
+static inline void *strdup2( const char *s ) {
+  char *const p = strdup( s );
+  if (!p) error( ENOMEM, 0, ALLOC_H_ENOMEM_MSG );
+  return p;
+}
+
 #endif
 
