@@ -11,8 +11,9 @@
   "\n\n"                                                               \
   "If this help list scrolls up off the screen "                       \
   "and you cannot see it all, "                                        \
-  "try `" PROG " --help | more'.  "                                    \
-  "Enter `man 1 " PROG "' for further information."
+  "try \"" PROG " --help | more\".  "                                  \
+  "This help list omits a few seldom-used options; "                   \
+  "enter \"man 1 " PROG "\" for complete documentation."
 #define ARGS_DOC         "RAMIFICATION..."
 #define OPT_DATA_FILE    1
 #define OPT_DATA_FILE_GZ 2
@@ -52,11 +53,6 @@ static const struct argp_option option[] = {
     "Color-code the output (recommended)"               ,
     0x111
   },
-  {
-    "no-latin1"     , 'L', 0, 0,
-    "Transliterate Latin-1 chars to ascii"              ,
-    0x111
-  },
 
   { 0, 0, 0, 0, "Other general options:"                      , 0x120 },
   {
@@ -142,26 +138,53 @@ static const struct argp_option option[] = {
     0x13d
   },
 
-  { 0, 0, 0, 0, "Other options:"                              , 0x140 },
+  { 0, 0, 0, 0, "Manual character-encoding selection:"  , 0x140 },
   {
-    "pri-one-color" , 'j', 0, 0,
-    "Do not differentiate priorities by color"          ,
+    "ascii"         , 'L', 0, 0,
+    "Output and accept arguments in ascii"              ,
     0x141
   },
   {
-    "selections",     's', 0, 0,
-    "Print only packages named on stdin (see dpkg(8))"  ,
+    "no-latin1"     , 'L', 0, OPTION_ALIAS,
+    0                                                   ,
+    0x141
+  },
+  {
+    "utf8"          , 'u', 0, 0,
+    "Output and accept arguments in utf-8"              ,
+    0x141
+  },
+  {
+    "latin1"        , 'l', 0, 0,
+    "Output and accept arguments in Latin-1"            ,
     0x141
   },
 
-  { 0, 0, 0, 0, "Seldom used options:"                        , 0x200 },
+  { 0, 0, 0, 0, "Other options:"                              , 0x150 },
   {
-    "data-file"     , OPT_DATA_FILE   , "FILE", 0,
+    "selections",     's', 0, 0,
+    "Print only packages named on stdin (see dpkg(8))"  ,
+    0x151
+  },
+  {
+    "ascii-dots",     '.', 0, 0,
+    "In the output, fill blanks with `.'"               ,
+    0x151
+  },
+
+  // { 0, 0, 0, OPTION_HIDDEN, "Seldom used options:"            , 0x200 },
+  {
+    "pri-one-color" , 'j', 0, OPTION_HIDDEN,
+    "Do not differentiate priorities by color"          ,
+    0x211
+  },
+  {
+    "data-file"     , OPT_DATA_FILE   , "FILE", OPTION_HIDDEN,
     "Substitute FILE for " DATA_FILE                    ,
     0x211
   },
   {
-    "data-file-gz"  , OPT_DATA_FILE_GZ, "FILE", 0,
+    "data-file-gz"  , OPT_DATA_FILE_GZ, "FILE", OPTION_HIDDEN,
     "Substitute FILE for " DATA_FILE_GZ                 ,
     0x211
   },
@@ -182,6 +205,8 @@ static error_t parse_opt(
 
     case 'w': opt.wide          = 1; break;
     case 'L': opt.no_latin1     = 1; break;
+    case 'u': opt.utf8          = 1; break;
+    case 'l': opt.latin1        = 1; break;
     case 'x': opt.expand_xref   = 1; break;
     case 'p': opt.plan          = 1; break;
     case 'r': opt.recursive     = 1; break;
@@ -197,6 +222,7 @@ static error_t parse_opt(
     case 's': opt.selections    = 1; break;
     case 'c': opt.color         = 1; break;
     case 'j': opt.pri_one_color = 1; break;
+    case '.': opt.ascii_dots    = 1; break;
 
     case '1':
         opt.no_subram           = 1;
@@ -306,6 +332,13 @@ static error_t parse_opt(
         opt.ram_cl_first = calloc2( 1, sizeof(struct ram_cl) );
         strncpy( opt.ram_cl_first->ram, zero_ram, N_DIG+1 );
       }
+      if ( opt.utf8 && opt.latin1 )
+        argp_error( state, "-u conflicts with -l" );
+
+      if ( opt.no_latin1 ) {
+        opt.utf8   = 0;
+        opt.latin1 = 0;
+      }
 
       if (
         (
