@@ -5,7 +5,7 @@
 #define _GNU_SOURCE
 
 #define PROG           "debram"
-#define VERSION        "0.6.1"
+#define VERSION        "0.6.4"
 
 #define DATA_FILE_BASENAME \
   "debram.txt"
@@ -31,7 +31,14 @@
 #define SHIFTWIDTH        2 /* the toc indent increment */
 #define NMAX_XREF       0xd
 
+#define CHARFMT_LATIN1 "LATIN1"
+#define CHARFMT_UTF8   "UTF8"
+#define SIZE_UTF8         6 /* the max no of bytes in a utf-8 char */
+#define SIZE_UTF8_RING    3 /* how many utf-8 buffers available */
+
 #define INDIC_XREF     "--->"
 
+#define DEBUG_LOCALE      0
+
 #endif
 
